@@ -17,7 +17,7 @@ use Zing::Registry;
 use FlightRecorder;
 use File::Spec;
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 our $name = 'zing <{command}> [<{app}>] [options]';
 
@@ -54,6 +54,16 @@ sub spec {
       type => 'string',
       flag => 'a',
     },
+    backlog => {
+      desc => 'Produce log output using the backlog',
+      type => 'flag',
+      flag => 'b',
+    },
+    global => {
+      desc => 'Tap the "global" log channel (defaults to "local")',
+      type => 'flag',
+      flag => 'g',
+    },
     process => {
       desc => 'Reduce log output by process name',
       type => 'string',
@@ -75,6 +85,12 @@ sub spec {
       type => 'string',
       flag => 'd',
     },
+    search => {
+      desc => 'Reduce log output by search string',
+      type => 'string',
+      flag => 's',
+      args => '@',
+    },
     tag => {
       desc => 'Reduce log output by process tag',
       type => 'string',
@@ -105,7 +121,12 @@ sub _handle_clean {
 sub _handle_logs {
   my ($self) = @_;
 
-  my $c = Zing::Channel->new(name => '$journal');
+  my $c = Zing::Channel->new(
+    name => '$journal',
+    (target => $self->opts->global ? 'global' : 'local')
+  );
+
+  $c->reset if $self->opts->backlog;
 
   while (1) {
     next unless my $info = $c->recv;
@@ -129,6 +150,12 @@ sub _handle_logs {
       next unless $tag =~ /$filter/;
     }
 
+    if (my $search = $self->opts->search) {
+      for my $search (@$search) {
+        @$lines = grep /$search/, @$lines;
+      }
+    }
+
     print STDOUT $from, ' ', $tag, ' ', $_, "\n" for @$lines;
   }
 
