@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 use Zing::Channel;
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 # ATTRIBUTES
 
@@ -33,44 +33,63 @@ fun new_channel($self) {
   Zing::Channel->new(name => $self->name)
 }
 
-has 'threshold' => (
-  is => 'ro',
-  isa => 'Str',
-  def => 1_000,
-);
-
 # BUILDERS
 
 fun BUILD($self) {
   return $self->apply if $self->channel->reset;
 }
 
+# SHIMS
+
+sub _copy {
+  my ($data) = @_;
+
+  if (!defined $data) {
+    return undef;
+  }
+  elsif (ref $data eq 'ARRAY') {
+    my $copy = [];
+    for (my $i = 0; $i < @$data; $i++) {
+      $copy->[$i] = _copy($data->[$i]);
+    }
+    return $copy;
+  }
+  elsif (ref $data eq 'HASH') {
+    my $copy = {};
+    for my $key (keys %$data) {
+      $copy->{$key} = _copy($data->{$key});
+    }
+    return $copy;
+  }
+  else {
+    return $data;
+  }
+}
+
 # METHODS
 
 method apply() {
-  if ($self->channel->renew) {
-    undef $self->{data} if $self->channel->size;
-  }
+  undef $self->{data} if $self->channel->renew;
 
   while (my $data = $self->recv) {
     my $op = $data->{op};
     my $key = $data->{key};
     my $val = $data->{val};
 
-    unless ($self->{data}) {
-      $self->{data} = $data->{snapshot} if $data->{snapshot};
+    if ($data->{snapshot} && !$self->{data}) {
+      $self->{data} = _copy($data->{snapshot});
     }
 
     local $@;
 
     if ($op eq 'decr') {
-      eval{($self->data->{$key} //= 0) -= ($val->[0] // 1)};
+      eval{($self->data->{$key} //= 0) -= ($val->[0] // 0)};
     }
     elsif ($op eq 'del') {
       eval{CORE::delete $self->data->{$key}};
     }
     elsif ($op eq 'incr') {
-      eval{($self->data->{$key} //= 0 ) += ($val->[0] // 1)};
+      eval{($self->data->{$key} //= 0 ) += ($val->[0] // 0)};
     }
     elsif ($op eq 'pop') {
       eval{CORE::pop @{$self->data->{$key}}};
@@ -95,13 +114,11 @@ method apply() {
 method change(Str $op, Str $key, Any @val) {
   my %fields = (
     key => $key,
-    snapshot => $self->data,
+    snapshot => _copy($self->data),
     time => time,
     val => [@val],
   );
 
-  $self->channel->drop if $self->channel->size >= $self->threshold;
-
   if ($op eq 'decr') {
     $self->send({ %fields, op => 'decr' });
   }
@@ -245,14 +262,6 @@ This attribute is read-only, accepts C<(Str)> values, and is required.
 
 =cut
 
-=head2 threshold
-
-  threshold(Str)
-
-This attribute is read-only, accepts C<(Str)> values, and is optional.
-
-=cut
-
 =head1 METHODS
 
 This package implements the following methods:
@@ -290,7 +299,7 @@ method is used internally and shouldn't need to be called directly.
 
   # given: synopsis
 
-  $domain->change('incr', 'karma');
+  $domain->change('incr', 'karma', 1);
 
 =back
 
