@@ -15,7 +15,7 @@ extends 'Zing::PubSub';
 
 use Zing::Term;
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 # ATTRIBUTES
 
@@ -180,7 +180,7 @@ The recv method receives a single new message from the mailbox.
 
   reply(HashRef $bag, HashRef $value) : Int
 
-The reply method sends a message to the mailbox represented by the C<$data>
+The reply method sends a message to the mailbox represented by the C<$bag>
 received and returns the size of the recipient mailbox.
 
 =over 4
